# ifndef yyClassification
# define yyClassification

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Classification_Exit) ARGS ((void));

extern void Classification ARGS ((tTree t));

extern void BeginClassification ARGS ((void));
extern void CloseClassification ARGS ((void));

# endif
